@@ -20,38 +20,42 @@
 #include "src/application/modelhandler.h"
 
 #include "src/presentation/frontends/qtfrontend/mainwindowgui.h"
+#include "src/presentation/frontends/qtfrontend/framebar/framebar.h"
 #include "src/domain/domainfacade.h"
+#include "src/technical/stringiterator.h"
 
 #include <QChar>
 #include <QProcess>
+#include <QStatusBar>
+#include <QFileDialog>
+#include <QPushButton>
+#include <QStringList>
+#include <QString>
+#include <QMessageBox>
 
 
-ModelHandler::ModelHandler ( QObject *parent, QStatusBar *sb, FrameBar *frameBar, 
-		ExternalChangeMonitor *changeMonitor, char *lastVisitedDir, const char *name ) 
-		: QObject(parent), frameBar(frameBar), statusBar(sb), 
-		lastVisitedDir(lastVisitedDir), changeMonitor(changeMonitor)
-{
+ModelHandler::ModelHandler ( QObject *parent, QStatusBar *sb, FrameBar *frameBar,
+		QString* lastVisitedDir, const char *name )
+		: QObject(parent), frameBar(frameBar), statusBar(sb),
+		lastVisitedDir(lastVisitedDir) {
 	fileDialog = NULL;
 	removeFramesButton = NULL;
 	setObjectName(name);
 }
 
 
-ModelHandler::~ModelHandler()
-{
+ModelHandler::~ModelHandler() {
 }
 
 
-void ModelHandler::setRemoveFramesButton( QPushButton * removeFramesButton )
-{
+void ModelHandler::setRemoveFramesButton(QPushButton* removeFramesButton) {
 	this->removeFramesButton = removeFramesButton;
 }
 
 
-void ModelHandler::chooseFrame()
-{
-	fileDialog = new QFileDialog((MainWindowGUI*)parent(), tr("Choose frames to add"),
-			QString::fromLocal8Bit(lastVisitedDir));
+void ModelHandler::chooseFrame() {
+	fileDialog = new QFileDialog((MainWindowGUI*)parent(),
+			tr("Choose frames to add"), *lastVisitedDir);
 	QStringList filters;
 	filters << "Images (*.png *.jpg *.jpeg  *.gif *.PNG *.JPG *.JPEG *.GIF)"
 			<< "Joint Photographic Ex. Gr. (*.jpg *.jpeg *.JPG *.JPEG)"
@@ -69,87 +73,114 @@ void ModelHandler::chooseFrame()
 	fileDialog->setFilters(filters);
 	fileDialog->setAcceptMode(QFileDialog::AcceptOpen);
 	fileDialog->setFileMode(QFileDialog::ExistingFiles);
-	
+
 	//PicturePreview* p = new PicturePreview(fileDialog);
-	
-	QObject::connect( fileDialog, SIGNAL(filesSelected (const QStringList &)), 
+
+	QObject::connect( fileDialog, SIGNAL(filesSelected (const QStringList &)),
 			this, SLOT(addFrames(const QStringList &)) );
-	
+
 	fileDialog->show();
 }
 
 
-// TODO: implement with std strings
-void ModelHandler::addFrames( const QStringList & fileNames)
-{
+class StringListIterator : public StringIterator {
+	QStringList::ConstIterator b;
+	QStringList::ConstIterator e;
+	std::string buffer;
+
+	void set() {
+		if (!atEnd()) {
+			buffer = b->toStdString();
+			buffer.c_str();
+		}
+	}
+
+public:
+	StringListIterator(QStringList::ConstIterator begin,
+			QStringList::ConstIterator end) : b(begin), e(end) {
+		set();
+	}
+	~StringListIterator() {
+	}
+	int count() {
+		int c = 0;
+		for (QStringList::ConstIterator i(b); i != e; ++i) {
+			++c;
+		}
+		return c;
+	}
+	bool atEnd() const {
+		return b == e;
+	}
+	const char* get() const {
+		return &buffer[0];
+	}
+	void next() {
+		++b;
+		set();
+	}
+};
+
+
+void ModelHandler::addFrames(const QStringList & fileNames) {
 	Logger::get().logDebug("addFrames in modelhandler");
-	QStringList names(fileNames);
-	
-	changeMonitor->suspendMonitor();
+
 	// the fileDialog pointer is NULL when adding of frames is
 	// done by drag 'n drop
 	if ( fileDialog != NULL ) {
 		fileDialog->hide();
-		strcpy( lastVisitedDir, fileDialog->directory().path().toLocal8Bit().constData() );
+		*lastVisitedDir = fileDialog->directory().path();
 	}
-	
-	if ( !names.isEmpty() ) {
-		vector<char*> fNames;
-		QStringList::Iterator it = names.begin();
-		while (it != names.end() ) {
-			QByteArray fileName = it->toLocal8Bit();
-			char *f = new char[fileName.length() + 1];
-			strcpy(f, fileName.constData());
-			fNames.push_back(f);
-			++it;
+
+	if ( !fileNames.isEmpty() ) {
+		StringListIterator fNames(fileNames.begin(), fileNames.end());
+		int scene = frameBar->getActiveScene();
+		int frame = frameBar->getActiveFrame() + 1;
+		if (scene < 0) {
+			scene = 0;
 		}
-		// trim to size :)
-		vector<char*>(fNames).swap(fNames);
-		DomainFacade::getFacade()->addFrames(fNames);
-		
-		// Cleanup
-		for (unsigned i = 0; i < fNames.size(); ++i) {
-			delete [] fNames[i];
-			fNames[i] = NULL;
-		}
-		
+		DomainFacade* facade = DomainFacade::getFacade();
+		int frameCount = facade->getSceneSize(scene);
+		if (frameCount < frame)
+			frame = frameCount;
+		if (frame < 0)
+			frame = 0;
+		facade->addFrames(scene, frame, fNames);
 		emit modelChanged();
 	}
-	changeMonitor->resumeMonitor();
 }
 
 
-void ModelHandler::addFrame( const QString &fileName )
-{
+void ModelHandler::addFrame( const QString &fileName ) {
 	if (fileDialog != NULL) {
 		fileDialog->hide();
-		strcpy( lastVisitedDir, fileDialog->directory().path().toLocal8Bit().constData() );
+		*lastVisitedDir = fileDialog->directory().path();
 	}
-	
+
 	QStringList fileNames;
 	fileNames.push_back(fileName);
 	this->addFrames(fileNames);
 }
 
 
-void ModelHandler::removeFrames()
-{
+void ModelHandler::removeFrames() {
 	if (removeFramesButton->isEnabled()) {
-		int selectionFrame = frameBar->getSelectionFrame();
-		int activeFrame = DomainFacade::getFacade()->getActiveFrameNumber();
+		int selectionFrame = frameBar->getSelectionAnchor();
+		int activeScene = frameBar->getActiveScene();
+		int activeFrame = frameBar->getActiveFrame();
 		int lowend = (selectionFrame < activeFrame ) ? selectionFrame : activeFrame;
 		int highend = (selectionFrame > activeFrame ) ? selectionFrame : activeFrame;
-	
-		DomainFacade::getFacade()->removeFrames(lowend, highend);
+
+		DomainFacade::getFacade()->removeFrames(activeScene, lowend,
+				highend - lowend + 1);
 		statusBar->showMessage( tr("Removed the selected frame"), 2000 );
 	}
 }
 
 
-void ModelHandler::newScene()
-{
-	int activeScene = DomainFacade::getFacade()->getActiveSceneNumber();
-	
+void ModelHandler::newScene() {
+	int activeScene = frameBar->getActiveScene();
+
 	if (activeScene >= 0) {
 		DomainFacade::getFacade()->newScene(activeScene+1);
 	}
@@ -166,21 +197,19 @@ void ModelHandler::newScene()
 }
 
 
-void ModelHandler::removeScene()
-{
-	DomainFacade::getFacade()->removeScene(DomainFacade::getFacade()->
-			getActiveSceneNumber());
+void ModelHandler::removeScene() {
+	int activeScene = frameBar->getActiveScene();
+	if (0 <= activeScene)
+		DomainFacade::getFacade()->removeScene(activeScene);
 }
 
 
-
 /*!
     \fn ModelHandler::editCurrentFrame()
  */
-int ModelHandler::editCurrentFrame()
-{
-	const char *gimpCommand = Util::checkCommand("gimp");
-	if (!gimpCommand) {
+int ModelHandler::editCurrentFrame() {
+	std::string gimpCommand;
+	if (!Util::checkCommand(&gimpCommand, "gimp")) {
 		QMessageBox::warning(static_cast<MainWindowGUI *>(parent()), tr("Warning"),
 			tr("You do not have Gimp installed on your system"),
 			QMessageBox::Ok, Qt::NoButton, Qt::NoButton);
@@ -188,8 +217,8 @@ int ModelHandler::editCurrentFrame()
 	}
 
 	// Determine the active scene and active frame.
-	int activeScene = DomainFacade::getFacade()->getActiveSceneNumber();
-	int activeFrame = DomainFacade::getFacade()->getActiveFrameNumber();
+	int activeScene = frameBar->getActiveScene();
+	int activeFrame = frameBar->getActiveFrame();
 
 	if (activeScene < 0 || activeFrame < 0) {
 		QMessageBox::warning(static_cast<MainWindowGUI *>(parent()), tr("Warning"),
@@ -197,28 +226,23 @@ int ModelHandler::editCurrentFrame()
 			QMessageBox::Ok, Qt::NoButton, Qt::NoButton);
 		return 1;
 	}
+	DomainFacade* facade = DomainFacade::getFacade();
+	facade->duplicateImage(activeScene, activeFrame);
+	const char *path = facade->getImagePath(activeScene, activeFrame);
 
-	Frame *frame = DomainFacade::getFacade()->getFrame(activeFrame, activeScene);
-	if (!frame) {
-		QMessageBox::warning(static_cast<MainWindowGUI *>(parent()), tr("Warning"),
-			tr("The active frame is corrupt"),
-			QMessageBox::Ok, Qt::NoButton, Qt::NoButton);
-		return 1;
-	}
-	
 	QStringList argList;
 	// arg0 are the options, and arg1 is the path of the frame.
 	// Start Gimp without splash screen.
-	argList.append(QLatin1String("--no-splash"));	
-	argList.append(QString::fromLocal8Bit(frame->getImagePath()));
+	argList.append(QLatin1String("--no-splash"));
+	argList.append(QString::fromLocal8Bit(path));
 
 	QProcess process;
-	if (!process.startDetached(QLatin1String(gimpCommand), argList)) {
+	if (!process.startDetached(QLatin1String(gimpCommand.c_str()), argList)) {
 		QMessageBox::warning(static_cast<MainWindowGUI *>(parent()), tr("Warning"),
 			tr("Failed to start Gimp!"),
 			QMessageBox::Ok, Qt::NoButton, Qt::NoButton);
 		return 1;
 	}
-	
+
 	return 0;
 }
