@@ -30,16 +30,9 @@ using namespace std;
 PreferencesTool* PreferencesTool::preferencesTool = 0;
 
 
-PreferencesTool::PreferencesTool()
-{
-	doc      = NULL;    
-	dtd      = NULL; 
-	rootNode = NULL;
-	versionNode = NULL;
-	
-	preferencesFile = NULL;
-	oldVersion = NULL;
-	
+PreferencesTool::PreferencesTool() :
+		doc(0), dtd(0), rootNode(0), preferences(0), versionNode(0),
+		preferencesFile(0), oldVersion(0) {
 	LIBXML_TEST_VERSION;
 }
 
@@ -210,16 +203,10 @@ bool PreferencesTool::setPreference(const char * key, const int attribute, bool
 }
 
 
-const char* PreferencesTool::getPreference(const char* key, const char* defaultValue)
-{
+const char* PreferencesTool::getPreference(const char* key) {
 	checkInitialized();
 	xmlNode *node = findNode(key);
-	if (node != NULL) {
-		return (const char*)xmlGetProp(node, BAD_CAST "attribute");
-	}
-	else {
-		return defaultValue;
-	}
+	return (const char*)xmlGetProp(node, BAD_CAST "attribute");
 }
 
 
@@ -227,17 +214,13 @@ int PreferencesTool::getPreference(const char * key, const int defaultValue)
 {
 	checkInitialized();
 	xmlNode *node = findNode(key);
-	if (node != NULL) {
-		char *tmp = (char*)xmlGetProp(node, BAD_CAST "attribute");
-		int ret = atoi(tmp);
-		if (xmlStrEqual((xmlChar*)tmp, BAD_CAST key)) {
-			xmlFree((xmlChar*)tmp);
-		}
-		return ret;
-	}
-	else {
+	if (!node) {
 		return defaultValue;
 	}
+	xmlChar *tmp = xmlGetProp(node, BAD_CAST "attribute");
+	int ret = atoi((char*)tmp);
+	xmlFree(tmp);
+	return ret;
 }
 
 
@@ -264,22 +247,20 @@ bool PreferencesTool::flushPreferences()
 }
 
 
-xmlNodePtr PreferencesTool::findNode(const char * key)
-{
+xmlNodePtr PreferencesTool::findNode(const char * key) {
 	//Search through the preferences for the element with a key which
 	//equals the key parameter.
 	xmlNode *node = preferences->children;
 	for (; node; node = node->next) {
 		if (node->type == XML_ELEMENT_NODE) {
-			xmlChar *prop = xmlGetProp(node, BAD_CAST "key");	
-			if (xmlStrEqual(prop, BAD_CAST key)) {
-				xmlFree(prop);
-				break;
-			}
+			xmlChar *prop = xmlGetProp(node, BAD_CAST "key");
+			int found = xmlStrEqual(prop, BAD_CAST key);
 			xmlFree(prop);
+			if (found)
+				return node;
 		}
 	}
-	return node;
+	return 0;
 }
 
 
@@ -312,3 +293,36 @@ void PreferencesTool::cleanTree()
 	rootNode        = NULL;
 	preferences     = NULL;
 }
+
+Preference::Preference(const char* key) : val(0), owns(false) {
+	val = PreferencesTool::get()->getPreference(key);
+	if (val)
+		owns = true;
+}
+
+Preference::Preference(const char* key, const char* defaultValue)
+	: val(0), owns(false) {
+	val = PreferencesTool::get()->getPreference(key);
+	if (val) {
+		owns = true;
+	} else {
+		val = defaultValue;
+	}
+}
+
+Preference::~Preference() {
+	if (owns)
+		xmlFree((xmlChar*)val);
+}
+
+const char* Preference::get() const {
+	return val;
+}
+
+bool Preference::equals(const char* str) {
+	if (str) {
+		return val? 0 == strcmp(val, str) : false;
+	} else {
+		return !val;
+	}
+}
