@@ -19,6 +19,8 @@
  ***************************************************************************/
 #include "nonguifrontend.h"
 
+#include "src/technical/stringiterator.h"
+
 #include <stdio.h>
 #include <unistd.h>
 #include <getopt.h>
@@ -27,60 +29,70 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <errno.h>
+#include <string>
+#include <string.h>
 
 
 NonGUIFrontend::NonGUIFrontend(DomainFacade *facadePtr)
-		: facadePtr(facadePtr)
-{
+		: facadePtr(facadePtr) {
 }
 
 
-NonGUIFrontend::~ NonGUIFrontend()
-{
+NonGUIFrontend::~ NonGUIFrontend() {
 }
 
 
-int NonGUIFrontend::run(int argc, char **argv) 
-{
+int NonGUIFrontend::run(int argc, char **argv) {
 	printf("NonGUIFrontend starts running ...\n");
 	return parseArguments(argc, argv);
 }
 
 
-void NonGUIFrontend::showProgress(const char *infoText, unsigned int) 
-{
+void NonGUIFrontend::showProgress(ProgressMessage message, int numOperations) {
 	// sets the stdout to be unbuffered
 	setvbuf(stdout, NULL, _IONBF,0);
-	printf("%s", infoText);
+	const char* infoText = "Please wait";
+	switch (message) {
+	case connectingCamera:
+		infoText = "Connecting camera";
+		break;
+	case exporting:
+		infoText = "Exporting";
+		break;
+	case importingFramesFromDisk:
+		infoText = "Importing frames from disk";
+		break;
+	case restoringProject:
+		infoText = "Restoring project";
+		break;
+	case savingScenesToDisk:
+		infoText = "Saving scenes to disk";
+		break;
+	}
+	printf("%s...", infoText);
 }
 
 
-void NonGUIFrontend::hideProgress() 
-{
+void NonGUIFrontend::hideProgress() {
 	printf("\nOperation finished!\n");
 	// sets the stdout the be buffered
 	setvbuf (stdout, NULL , _IOFBF , 1024);
 }
 
 
-void NonGUIFrontend::updateProgress(int) 
-{
+void NonGUIFrontend::updateProgress(int) {
 	printf(".");
 }
 
 
-void NonGUIFrontend::setProgressInfo(const char *infoText) 
-{
-	printf("\n%s\n", infoText);
+bool NonGUIFrontend::isOperationAborted() {
+	return false;
 }
 
+void NonGUIFrontend::processEvents() {
+}
 
-bool NonGUIFrontend::isOperationAborted() { return false; }
-void NonGUIFrontend::processEvents() {}
-
-
-int NonGUIFrontend::parseArguments(int argc, char **argv)
-{
+int NonGUIFrontend::parseArguments(int argc, char **argv) {
 	while (1) {
 		static struct option longOptions[] =
 			{
@@ -91,43 +103,43 @@ int NonGUIFrontend::parseArguments(int argc, char **argv)
 				{"export", 0, 0, 'e'},
 				{0, 0, 0, 0}
 			};
-		
+
 		/* getopt_long  stores the option index here. */
 		int optionIndex = 0;
 		int c = getopt_long(argc, argv, "a:c:s:e:", longOptions, &optionIndex);
-	
+
 		/* Detect the end of the options. */
 		if (c == -1) {
 			break;
 		}
-	
+
 		switch (c) {
 			case 0:
 				/* If this option set a flag, do nothing else now. */
 				break;
-	
+
 			case 'a':
-				//printf ("option --addFrames with arument %s\n", optarg);
+				//printf ("option --addFrames with argument %s\n", optarg);
 				addFrames(optarg);
 				break;
-	
+
 			case 'c':
-				printf ("option --capture with arument %s\n", optarg);
+				printf ("option --capture with argument %s\n", optarg);
 				break;
-	
+
 			case 'e':
-				printf ("option --export with arument %s\n", optarg);
+				printf ("option --export with argument %s\n", optarg);
 				break;
-	
+
 			case 's':
-				//printf ("option --save with arument %s\n", optarg);
+				//printf ("option --save with argument %s\n", optarg);
 				save(optarg);
 				break;
-	
+
 			case '?':
 				/* getopt_long  already printed an error message. */
 				break;
-	
+
 			default:
 				return 1;
 		}
@@ -135,113 +147,101 @@ int NonGUIFrontend::parseArguments(int argc, char **argv)
 	return 0;
 }
 
-
-void NonGUIFrontend::addFrames(const char *directory)
-{
-	// returns a absoulte path which is allocated with new[]
-	const char *dir = getAbsolutePath(directory);
-
-	DIR *dp = opendir(dir);
-	if (dp) {
-		vector<char*> frames;
-		struct dirent *ep;
-		struct stat st;
-
-		while ( (ep = readdir(dp)) ) {
-			char *fileName = new char[PATH_MAX];
-			snprintf(fileName, PATH_MAX, "%s%s", dir, ep->d_name);
-			stat(fileName, &st);
-			// is a regular file, not a directory
-			if ( S_ISREG(st.st_mode) != 0 && strstr(fileName, "snd") == NULL ) {
-				frames.push_back(fileName);
-			}
-			else {
-				delete [] fileName;
-			}
-			fileName = NULL;
-		}
-		closedir(dp);
-		
-		vector<char*>(frames).swap(frames);
-		facadePtr->addFrames(frames);
-
-		unsigned int numElem = frames.size();
-		for (unsigned int i = 0; i < numElem; ++i) {
-			delete [] frames[i];
-		}
-		
-		char tmpDir[PATH_MAX] = {0};
-		snprintf(tmpDir, sizeof(tmpDir), "%s/.stopmotion/tmp/", getenv("HOME"));
-		int success = checkFiles(tmpDir);
-		printf("Successfully copied %d files from %s to %s\n", success, dir, tmpDir);
+class DirIterator : public StringIterator {
+	std::string buffer;
+	std::string::size_type dirLen;
+	DIR *dp;
+	struct dirent *ep;
+public:
+	DirIterator(const char* path)
+			: buffer(path), dirLen(0), dp(opendir(path)) {
+		dirLen = buffer.size();
+		next();
 	}
-	else {
-		fprintf (stderr, "Couldn't open directory: %s; %s\n", dir, strerror (errno));
+	~DirIterator() {
+		if (dp)
+			closedir(dp);
 	}
-	
-	delete [] dir;
+	int count() {
+		int c = 0;
+		if (dp) {
+			while (atEnd()) {
+				++c;
+				next();
+			}
+			rewinddir(dp);
+			next();
+		}
+		return c;
+	}
+	bool atEnd() const {
+		return !dp || !ep;
+	}
+	const char* get() const {
+		return &buffer[0];
+	}
+	void next() {
+		if (dp) {
+			ep = readdir(dp);
+			while (ep && ep->d_type != DT_REG)
+				ep = readdir(dp);
+			if (ep) {
+				buffer.resize(dirLen);
+				buffer.append(ep->d_name);
+				buffer.c_str();
+			}
+		}
+	}
+};
+
+void NonGUIFrontend::addFrames(const char *directory) {
+	std::string dir;
+	getAbsolutePath(dir, directory);
+	DirIterator di(dir.c_str());
+	facadePtr->addFrames(0, 0, di);
 }
 
 
-void NonGUIFrontend::save(const char *directory)
-{
+void NonGUIFrontend::save(const char *directory) {
 	// returns a absoulte path which is allocated with new[]
-	const char *dir = getAbsolutePath(directory);
-	facadePtr->saveProject(dir);
-	
-	char tmp[PATH_MAX] = {0};
-	snprintf(tmp, sizeof(tmp), "%simages/", dir);
-	int saved = checkFiles(tmp);
-	printf("Successfully saved %d files in %s\n", saved, tmp);
-	snprintf(tmp, sizeof(tmp), "%s/.stopmotion/tmp/", getenv("HOME"));
-	int numFiles = checkFiles(tmp);
-	printf("Successfully removed %d files from %s\n", saved - numFiles, tmp);
-	
-	delete [] dir;
+	std::string dir;
+	getAbsolutePath(dir, directory);
+	facadePtr->saveProject(dir.c_str());
 }
 
 
-const char* NonGUIFrontend::getAbsolutePath(const char *path)
-{
-	char *tmp = new char[PATH_MAX];
-	
+void NonGUIFrontend::getAbsolutePath(std::string& out, const char *path) {
+	if (!path || path[0] == '\0') {
+		out = "/";
+		return;
+	}
 	// isn't an absolute path
 	if (path[0] != '/') {
 		// make it absolute
-		snprintf(tmp, PATH_MAX, "%s/%s", getenv("PWD"), path);
+		out = getenv("PWD");
+		out.append("/");
+		out.append(path);
+	} else {
+		out = path;
 	}
-	else {
-		strncpy(tmp, path, PATH_MAX);
-	}
-	
-	struct stat st;
-	stat(tmp, &st);
-	// if it is a directory
-	if ( S_ISDIR(st.st_mode) != 0) {
-		int len = strlen(tmp);
-		// and doesn't ends with a '/'
-		if ( tmp[len - 1] != '/' ) {
-			// append a '/'
-			snprintf(tmp, PATH_MAX, "%s/", tmp);
-		}
-	}
-	
-	return tmp;
+	// ensure it ends in /
+	if (out[out.size() - 1] != '/')
+		out.append("/");
 }
 
 
-int NonGUIFrontend::checkFiles(const char *directory)
-{
+int NonGUIFrontend::checkFiles(const char *directory) {
 	int numSuccessFull = 0;
 	DIR *dp = opendir(directory);
-	
+
 	if (dp) {
 		struct dirent *ep;
 		struct stat st;
 		char tmp[PATH_MAX] = {0};
-		
+
 		while ( (ep = readdir(dp)) ) {
 			snprintf(tmp, sizeof(tmp), "%s%s", directory, ep->d_name);
+			tmp[sizeof(tmp) - 1] = '\0';  // ensure null-terminated
 			stat(tmp, &st);
 			// is a regular file, not a directory
 			if ( S_ISREG(st.st_mode) != 0) {
@@ -253,15 +253,14 @@ int NonGUIFrontend::checkFiles(const char *directory)
 	else {
 		fprintf (stderr, "Couldn't open directory: %s; %s\n",directory, strerror (errno));
 	}
-	
+
 	return numSuccessFull;
 }
 
 
-void NonGUIFrontend::reportError( const char *message, int id )
-{
+void NonGUIFrontend::reportError( const char *message, int id ) {
 	id = id != 0 && id != 1 ? 0 : id;
-	
+
 	if (id == 0) {
 		printf("Warning: %s\n", message);
 	}
@@ -271,13 +270,11 @@ void NonGUIFrontend::reportError( const char *message, int id )
 }
 
 
-int NonGUIFrontend::askQuestion(const char *)
-{
+int NonGUIFrontend::askQuestion(Question) {
 	return 1;
 }
 
 
-int NonGUIFrontend::runExternalCommand(const char *)
-{
+int NonGUIFrontend::runExternalCommand(const char *) {
 	return 1;
 }
