@@ -1,6 +1,6 @@
 /***************************************************************************
- *   Copyright (C) 2005-2008 by Bjoern Erik Nilsen & Fredrik Berg Kjoelstad*
- *   bjoern.nilsen@bjoernen.com & fredrikbk@hotmail.com                    *
+ *   Copyright (C) 2005-2014 by Linuxstopmotion contributors;              *
+ *   see the AUTHORS file for details.                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -20,12 +20,24 @@
 #include "qtfrontend.h"
 
 #include "src/application/externalcommand.h"
+#include "src/presentation/frontends/qtfrontend/mainwindowgui.h"
+#include "src/foundation/preferencestool.h"
+#include "src/foundation/logger.h"
+#include "src/technical/util.h"
+#include "src/domain/animation/workspacefile.h"
 
+#include <QProgressDialog>
+#include <QProgressBar>
+#include <QTimer>
+#include <QApplication>
+#include <QLabel>
 #include <QtGui>
 
 #include <cstring>
 #include <unistd.h>
 #include <sstream>
+#include <stdio.h>
+#include <assert.h>
 
 QtFrontend::QtFrontend(int &argc, char **argv)
 {
@@ -65,19 +77,35 @@ int QtFrontend::run(int, char **)
 }
 
 
-void QtFrontend::showProgress(const char* operation, unsigned int numOperations)
-{
-	if (numOperations > 0) {
-		progressDialog = new QProgressDialog( operation, tr("Cancel"), 0, numOperations,mw);
-		progressDialog->show();
+void QtFrontend::showProgress(ProgressMessage message, int numOperations) {
+	QString msg = tr("Please wait...");
+	switch (message) {
+	case connectingCamera:
+		msg = tr("Connecting camera...");
+		break;
+	case importingFramesFromDisk:
+		msg = tr("Importing frames from disk");
+		break;
+	case exporting:
+		msg = tr("Exporting...");
+		break;
+	case restoringProject:
+		msg = tr("Restoring project...");
+		break;
+	case savingScenesToDisk:
+		msg = tr("Saving scenes to disk...");
+		break;
 	}
-	else {
+	if (numOperations > 0) {
+		progressDialog = new QProgressDialog(msg, tr("Cancel"), 0,
+				numOperations, mw);
+		progressDialog->show();
+	} else {
 		progressBar = new QProgressBar;
 		progressBar->setFixedWidth(150);
-		infoText = new QLabel(operation);
+		infoText = new QLabel(msg);
 		mw->statusBar()->addWidget(infoText);
 		mw->statusBar()->addWidget(progressBar);
-
 		timer = new QTimer();
 		connect( timer, SIGNAL( timeout() ), this, SLOT( updateProgressBar() ) );
         timer->start(10);
@@ -85,14 +113,12 @@ void QtFrontend::showProgress(const char* operation, unsigned int numOperations)
 }
 
 
-void QtFrontend::hideProgress()
-{
+void QtFrontend::hideProgress() {
 	if (progressDialog) {
 		progressDialog->hide();
 		delete progressDialog;
 		progressDialog = NULL;
-	}
-	else if (progressBar) {
+	} else if (progressBar) {
 		timer->stop();
 		progressBar->hide();
 		mw->statusBar()->removeWidget(progressBar);
@@ -107,24 +133,21 @@ void QtFrontend::hideProgress()
 }
 
 
-void QtFrontend::updateProgress(int numOperationsDone)
-{
+void QtFrontend::updateProgress(int numOperationsDone) {
 	if (progressDialog) {
 		progressDialog->setValue(numOperationsDone);
 	}
 }
 
 
-void QtFrontend::setProgressInfo(const char *infoText)
-{
+void QtFrontend::setProgressInfo(const char *infoText) {
 	if (progressDialog) {
 		progressDialog->setLabelText(infoText);
 	}
 }
 
 
-bool QtFrontend::isOperationAborted()
-{
+bool QtFrontend::isOperationAborted() {
 	if (progressDialog) {
 		return progressDialog->wasCanceled();
 	}
@@ -132,14 +155,12 @@ bool QtFrontend::isOperationAborted()
 }
 
 
-void QtFrontend::processEvents()
-{
+void QtFrontend::processEvents() {
 	stApp->processEvents();
 }
 
 
-void QtFrontend::updateProgressBar()
-{
+void QtFrontend::updateProgressBar() {
     int p = progressBar->value();
     progressBar->setValue(++p);
 }
@@ -165,40 +186,33 @@ void QtFrontend::initializePreferences()
 	Logger::get().logDebug("Loading preferencestool");
 
 	PreferencesTool *prefs = PreferencesTool::get();
-	string preferencesFile = getenv("HOME");
-	preferencesFile += "/.stopmotion/preferences.xml";
-	string oldPrefsFile = preferencesFile + ".OLD";
+	WorkspaceFile preferencesFile(WorkspaceFile::preferencesFile);
+	WorkspaceFile oldPrefsFile(WorkspaceFile::preferencesFileOld);
 
 	// Has to check this before calling setPreferencesFile(...) because
 	// the function creates the file if it doesn't exist.
-	int prefsFileExists = access(preferencesFile.c_str(), R_OK);
+	int prefsFileExists = access(preferencesFile.path(), R_OK);
 	if (prefsFileExists != -1) {
-		ostringstream copyCmd;
-		copyCmd << "/bin/cp " << preferencesFile << " " << oldPrefsFile;
-		system(copyCmd.str().c_str());
+		Util::copyFile(oldPrefsFile.path(), preferencesFile.path());
 	}
 
 	// If file doesn't exist or has wrong version number
-	if ( !prefs->setPreferencesFile(preferencesFile.c_str(), "0.8") ) {
+	if ( !prefs->setPreferencesFile(preferencesFile.path(), "0.8") ) {
 		// File doesn't exist
 		if (prefsFileExists == -1) {
 			setDefaultPreferences(prefs);
 		}
 		// Has wrong version number
 		else {
-			QString question(tr(
-					"A newer version of the preferences file with few more default\n"
-					"values exists. Do you want to use this one? (Your old preferences\n "
-					"will be saved in ~/.stopmotion/preferences.xml.OLD)"));
-			int useNewPrefsFile = askQuestion(question.toUtf8());
+			int useNewPrefsFile = askQuestion(Frontend::useNewerPreferences);
 			// Use new preferences
 			if (useNewPrefsFile == 0) { // 0 = yes
 				setDefaultPreferences(prefs);
 			}
 			// Use old preferences
 			else {
-				rename(oldPrefsFile.c_str(), preferencesFile.c_str());
-				prefs->setPreferencesFile(preferencesFile.c_str(), prefs->getOldVersion());
+				rename(oldPrefsFile.path(), preferencesFile.path());
+				prefs->setPreferencesFile(preferencesFile.path(), prefs->getOldVersion());
 
 				// Update version
 				prefs->setVersion("0.8");
@@ -310,26 +324,33 @@ void QtFrontend::setDefaultPreferences(PreferencesTool *prefs)
 	//-------------------------------------------------------------------------
 }
 
-
 void QtFrontend::updateOldPreferences(PreferencesTool *prefs)
 {
 	// Replace all occurences of '(DEFAULTPATH)' with '$IMAGEFILE'  (version 0.3 and 0.4)
 	// Replace all occurences of '/dev/xxx' with $VIDEODEVICE (version < 0.7)
 	int numImports = prefs->getPreference("numberofimports", 1);
 	for (int i = 0; i < numImports; ++i) {
-		string start( prefs->getPreference(QString("importstartdaemon%1").arg(i).toUtf8().constData(), "") );
+		Preference startPref(QString("importstartdeamon%1")
+				.arg(i).toUtf8().constData(), "");
+		std::string start(startPref.get());
 		int index = start.find("(DEFAULTPATH)");
 		if (index != -1) {
-			start.replace(index, strlen("(DEFAULTPATH)"), string("$IMAGEFILE"));
+			start.replace(index, strlen("(DEFAULTPATH)"),
+					std::string("$IMAGEFILE"));
 		}
 		QString s(start.c_str());
-		s.replace( QRegExp("/dev/(v4l/){0,1}video[0-9]{0,1}"), QString("$VIDEODEVICE") );
-		prefs->setPreference( QString("importstartdaemon%1").arg(i).toUtf8().constData(), s.toUtf8().constData());
+		s.replace( QRegExp("/dev/(v4l/){0,1}video[0-9]{0,1}"),
+				QString("$VIDEODEVICE") );
+		prefs->setPreference( QString("importstartdeamon%1")
+				.arg(i).toUtf8().constData(), s.toUtf8().constData());
 
-		string prepoll( prefs->getPreference(QString("importprepoll%1").arg(i).toUtf8().constData(), "") );
+		Preference prepollPref(QString("importprepoll%1")
+				.arg(i).toUtf8().constData(), "");
+		std::string prepoll(prepollPref.get());
 		index = prepoll.find("(DEFAULTPATH)");
 		if (index != -1) {
-			prepoll.replace(index, strlen("(DEFAULTPATH)"), string("$IMAGEFILE"));
+			prepoll.replace(index, strlen("(DEFAULTPATH)"),
+					std::string("$IMAGEFILE"));
 		}
 		QString ss(prepoll.c_str());
 		ss.replace( QRegExp("/dev/(v4l/){0,1}video[0-9]{0,1}"), QString("$VIDEODEVICE") );
@@ -338,16 +359,20 @@ void QtFrontend::updateOldPreferences(PreferencesTool *prefs)
 }
 
 
-int QtFrontend::askQuestion(const char *question)
-{
-	int ret = QMessageBox::question(0,
-			tr("Question"),
-			QString::fromUtf8(question),
-			QMessageBox::Yes, QMessageBox::No, QMessageBox::NoButton);
-	if (ret == QMessageBox::Yes) {
-		return 0;
+int QtFrontend::askQuestion(Question question) {
+	QString text;
+	switch (question) {
+	case useNewerPreferences:
+		text = tr(
+				"A newer version of the preferences file with few more default\n"
+				"values exists. Do you want to use this one? (Your old preferences\n "
+				"will be saved in ~/.stopmotion/preferences.xml.OLD)");
+		break;
 	}
-	return 1;
+	int ret = QMessageBox::question(0,
+			tr("Question"), text,
+			QMessageBox::Yes, QMessageBox::No, QMessageBox::NoButton);
+	return ret == QMessageBox::Yes? 0 : 1;
 }
 
 
@@ -358,3 +383,12 @@ int QtFrontend::runExternalCommand(const char *command)
 	ec->run( QString::fromLocal8Bit(command) );
 	return 0;
 }
+
+
+void QtFrontend::setUndoRedoEnabled() {
+	mw->activateMenuOptions();
+}
+
+void QtFrontend::openProject(const char* file) {
+	mw->openProject(file);
+}
