@@ -22,62 +22,62 @@
         <translation>Hovedutviklere</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="50"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="52"/>
         <source>A&amp;uthors</source>
         <translation>&amp;Forfattere</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="54"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="56"/>
         <source>Translation</source>
         <translation>Oversettelse</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="55"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="57"/>
         <source>Czech</source>
         <translation>Tsjekkisk</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="56"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="58"/>
         <source>Slovenian</source>
         <translation>Slovensk</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="57"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="59"/>
         <source>French</source>
         <translation>Fransk</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="63"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="65"/>
         <source>Logo</source>
         <translation>Logo</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="65"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="67"/>
         <source>Coordinating</source>
         <translation>Koordinering</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="68"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="70"/>
         <source>Testing</source>
         <translation>Testing</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="79"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="81"/>
         <source>&amp;Thanks To</source>
         <translation>&amp;Takk til</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="84"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="86"/>
         <source>&amp;Licence Agreement</source>
         <translation>&amp;Lisensavtale</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="86"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="88"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="99"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="101"/>
         <source>About</source>
         <translation>Om</translation>
     </message>
@@ -87,25 +87,30 @@
         <translation>Dette er Stopmotion - et program for å lage stillbildeanimasjoner.</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="58"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="60"/>
         <source>German</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="59"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="61"/>
         <source>Portuguese</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="60"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="62"/>
         <source>Spanish</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="61"/>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="63"/>
         <source>Swedish</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../src/presentation/frontends/qtfrontend/aboutdialog.cpp" line="50"/>
+        <source>Contributors</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CameraHandler</name>
@@ -330,7 +335,7 @@
 <context>
     <name>Form</name>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="36"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.ui" line="33"/>
         <source>Form</source>
         <translation>Form</translation>
     </message>
@@ -389,12 +394,12 @@
 <context>
     <name>FrameView</name>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="436"/>
+        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="444"/>
         <source>Warning</source>
         <translation>Advarsel</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="427"/>
+        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="435"/>
         <source>Grabbing failed. This may happen if you try
 to grab from an invalid device. Please check
 your grabber settings in the preferences menu.</source>
@@ -403,7 +408,7 @@ prøver å fange bilde fra en ugyldig enhet.
 Vennligst sjekk at preferansene er riktige.</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="438"/>
+        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="446"/>
         <source>You have to define an image grabber to use.
 This can be set in the preferences menu.</source>
         <translation>Du må velge et program som kan fange bilder.
@@ -415,7 +420,7 @@ Dette kan settes i preferanse-menyen.</translation>
         <translation>Forhåndskommando eksisterer ikke</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="382"/>
+        <location filename="../src/presentation/frontends/qtfrontend/frameview.cpp" line="386"/>
         <source>You do not have the given grabber installed on your system</source>
         <translation>Programmet du har satt til å fange bilder eksisterer ikke på ditt system</translation>
     </message>
@@ -553,12 +558,12 @@ Dette kan settes i preferanse-menyen.</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="346"/>
-        <source>Start deamon</source>
+        <source>Start daemon</source>
         <translation>Start nisse</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/importtab.cpp" line="347"/>
-        <source>Stop deamon</source>
+        <source>Stop daemon</source>
         <translation>Stopp nisse</translation>
     </message>
     <message>
@@ -943,7 +948,7 @@ Dette kan settes i preferanse-menyen.</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/mainwindowgui.cpp" line="571"/>
-        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automaticly be saved to the previously selected file.&lt;/p&gt;</source>
+        <source>&lt;h4&gt;Save&lt;/h4&gt; &lt;p&gt;&lt;em&gt;Saves&lt;/em&gt; the current animation as a Stopmotion project file. &lt;BR&gt;If this project has been saved before it will automatically be saved to the previously selected file.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Lagre&lt;/h4&gt;&lt;p&gt;&lt;em&gt;Lagrer&lt;/em&gt; nåværende animasjon som en Stopmotion prosjektfil. &lt;BR&gt; Hvis prosjektet allerede er lagret til fil, vil det automatisk lagre til denne filen. &lt;/p&gt;</translation>
     </message>
     <message>
@@ -1128,15 +1133,40 @@ to check your settings in the preferences menu?</source>
 <context>
     <name>ModelHandler</name>
     <message>
-        <location filename="../src/application/modelhandler.cpp" line="52"/>
+        <location filename="../src/application/modelhandler.cpp" line="53"/>
         <source>Choose frames to add</source>
         <translation>Velg frames å legge til</translation>
     </message>
     <message>
-        <location filename="../src/application/modelhandler.cpp" line="142"/>
+        <location filename="../src/application/modelhandler.cpp" line="143"/>
         <source>Removed the selected frame</source>
         <translation>Fjernet den valgte frame</translation>
     </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="216"/>
+        <source>Warning</source>
+        <translation type="unfinished">Advarsel</translation>
+    </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="184"/>
+        <source>You do not have Gimp installed on your system</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="195"/>
+        <source>There is no active frame to open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="203"/>
+        <source>The active frame is corrupt</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/application/modelhandler.cpp" line="217"/>
+        <source>Failed to start Gimp!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PreferencesMenu</name>
@@ -1235,12 +1265,12 @@ to check your settings in the preferences menu?</source>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="230"/>
-        <source>vgrabbj VGA deamon</source>
-        <translation>vgrabbj VGA deamon</translation>
+        <source>vgrabbj VGA daemon</source>
+        <translation>vgrabbj VGA daemon</translation>
     </message>
     <message>
         <location filename="../src/presentation/frontends/qtfrontend/qtfrontend.cpp" line="232"/>
-        <source>Starts vgrabbj as a deamon. Pretty fast.</source>
+        <source>Starts vgrabbj as a daemon. Pretty fast.</source>
         <translation>Starter vgrabbj som en nisse. Veldig kjapt.</translation>
     </message>
     <message>
@@ -1407,139 +1437,144 @@ lagret som ~/.stopmotion/preferences.xml.OLD)</translation>
         <translation type="obsolete">Antall bilder mikset på:</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="202"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="210"/>
         <source>FPS chooser</source>
         <translation>FPS-velger</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="279"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="294"/>
         <source>&lt;h4&gt;FPS chooser&lt;/h4&gt; &lt;p&gt;By changing the value in this chooser you set which speed the animation in the &lt;b&gt;FrameView&lt;/b&gt; should run at.&lt;/p&gt; &lt;p&gt;To start an animation press the &lt;b&gt;Run Animation&lt;/b&gt; button.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;FPS-velger&lt;/h4&gt; &lt;p&gt;Ved å forandre verdien i dette feltet kan du bestemme hastigheten (i bilder per sekund) animasjonen skal kjøre i.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="206"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="214"/>
         <source>Mix</source>
         <translation>Miks</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="207"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="215"/>
         <source>Diff</source>
         <translation>Forskjell</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="203"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="211"/>
         <source>Number of images:</source>
         <translation>Antall bilder:</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="208"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="216"/>
         <source>Playback</source>
         <translation>Avspilling</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="222"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="230"/>
         <source>&lt;h4&gt;Add Frames (CTRL+F)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;add&lt;/em&gt; frames to the animation.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Legg til bilder (CTRL+F)&lt;/h4&gt;&lt;p&gt;Trykk på denne knappen for å &lt;em&gt;legge til&lt;/em&gt; bilder til animasjonen.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="229"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="237"/>
         <source>&lt;h4&gt;Remove Selection (Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected frames from the animation.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Fjern valgte bilder&lt;/h4&gt;&lt;p&gt;Trykk på denne knappen for  å &lt;em&gt;fjerne&lt;/em&gt; de valgte bildene fra animasjonen.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="236"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="244"/>
         <source>&lt;h4&gt;New Scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;create&lt;/em&gt; a new &lt;em&gt;scene&lt;/em&gt; to the animation.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Ny scene (CTRL+E)&lt;/h4&gt; &lt;p&gt;Trykk på denne knappen for å &lt;em&gt;legge til en ny scene&lt;/em&gt;.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="243"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="251"/>
         <source>&lt;h4&gt;Remove Scene (SHIFT+Delete)&lt;/h4&gt; &lt;p&gt;Click this button to &lt;em&gt;remove&lt;/em&gt; the selected scene from the animation.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Fjern scener (SHIFT+Delete)&lt;/h4&gt;&lt;p&gt;Trykk på denne knappen for å &lt;em&gt;fjerne&lt;/em&gt; de valgte scenene fra animasjonen. &lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="249"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="257"/>
         <source>&lt;h4&gt;Toggle camera on/off (C)&lt;/h4&gt; &lt;p&gt;Click this button to toggle the camera on and off&lt;/p&gt; </source>
         <translation>&lt;h4&gt;Skru av/på kamera&lt;/h4&gt; &lt;p&gt;Trykk på denne knappen for å skru av og på kameraet&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="257"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="272"/>
         <source>&lt;h4&gt;Capture Frame (Space)&lt;/h4&gt; &lt;p&gt;Click on this button to &lt;em&gt;capture&lt;/em&gt; a frame from the camera an put it in the animation&lt;/p&gt; &lt;p&gt; This can also be done by pressing the &lt;b&gt;Space key&lt;/b&gt;&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Ta et bilde (Space)&lt;/h4&gt;&lt;p&gt;Trykk på denne knappen for å &lt;em&gt;ta et bilde&lt;/em&gt; og legge det til i animasjonen.&lt;/p&gt;
 &lt;p&gt;Dette kan også gjøres ved å trykke på &lt;b&gt;space-tasten&lt;/b&gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="268"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="283"/>
         <source>&lt;h4&gt;Number of images&lt;/h4&gt; &lt;p&gt;By changing the value in this slidebar you can specify how many images backwards in the animation which should be mixed on top of the camera or if you are in playback mode: how many images to play. &lt;/p&gt; &lt;p&gt;By mixing the previous image(s) onto the camera you can more easily see how the next shot will be in relation to the other, therby making a smoother stop motion animation!&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Antall bilder&lt;/h4&gt;&lt;p&gt;Her kan du sette hvor mange tidligere bilder som skal brukes i den gitte modusen (enten playback eller miks).&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="283"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="298"/>
         <source>&lt;h4&gt;Play animation (K, P)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Spill av animasjon (K, P)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="286"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="301"/>
         <source>&lt;h4&gt;Stop animation (K, P)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Stopp animasjon (K, P)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="289"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="304"/>
         <source>&lt;h4&gt;Previous frame (J, Left)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Forrige bilde (J, venstre)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="292"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="307"/>
         <source>&lt;h4&gt;Next frame (L, Right)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Neste bilde (L, høyre) &lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="295"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="310"/>
         <source>&lt;h4&gt;Previous scene (I)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Forrige scene (l)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="298"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="313"/>
         <source>&lt;h4&gt;Next scene (O)&lt;/h4&gt;</source>
         <translation>&lt;h4&gt;Neste scene (O)&lt;/h4&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="303"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="318"/>
         <source>&lt;h4&gt;Loop animation (CTRL+L)&lt;/h4&gt; &lt;p&gt;With this button you can set whether you want the animation to play to the end, or to loop indefinetly.&lt;/p&gt;</source>
         <translation>&lt;h4&gt;Spill av kontinuerlig (begynn på starten igjen når animasjonen er ferdig, CTRL+L)&lt;/h4&gt;&lt;p&gt;Her kan du velge om du ønsker å spille av animasjonen kontinuerlig, eller om den skal stoppe når den er ferdig.&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="393"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="408"/>
         <source>Notice</source>
         <translation>Notis</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="396"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="411"/>
         <source>Playback only currently works when running the grabber 
-as a deamon. Go to the preferences menu (CTRL+P) to switch 
-to running the image grabbing as a deamon.</source>
+as a daemon. Go to the preferences menu (CTRL+P) to switch 
+to running the image grabbing as a daemon.</source>
         <translation>Playback fungerer kun når du gjører bildefangst-programmet som 
 en nisse. Gå til preferansemenyen (CTRL+P ) for å sette at 
 programmet skal kjøres som en nisse.</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="209"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="217"/>
         <source>Auto</source>
         <translation>Auto</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="213"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="221"/>
         <source>Pr sec</source>
         <translation>Pr sek</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="214"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="222"/>
         <source>Pr min</source>
         <translation>Pr min</translation>
     </message>
     <message>
-        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="215"/>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="223"/>
         <source>Pr hr</source>
         <translation>Pr time</translation>
     </message>
+    <message>
+        <location filename="../src/presentation/frontends/qtfrontend/toolsmenu.cpp" line="264"/>
+        <source>&lt;h4&gt;Launch Gimp&lt;/h4&gt; &lt;p&gt;Click this button to open the active frame in Gimp&lt;/p&gt; &lt;p&gt;Note that you can also drag images from the frame bar and drop them on Gimp&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
